netapp_ontap.models.snapmirror_relationship_transfer API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.snapmirror_relationship_transfer`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class SnapmirrorRelationshipTransferSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the SnapmirrorRelationshipTransfer object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `bytes_transferred: Size GET POST PATCH`

    Total bytes transferred in the current or last successful transfer.

  `end_time: ImpreciseDateTime GET POST PATCH`

    End time of the last transfer.

    Example: 2020-12-03T02:36:19.000+0000

  `last_updated_time: ImpreciseDateTime GET POST PATCH`

    Last updated time of the bytes transferred in the current transfer.

    Example: 2023-09-14T22:39:19.000+0000

  `links: SelfLink GET`

    The links field of the snapmirror_relationship_transfer.

  `state: str GET POST PATCH`

    The state field of the snapmirror_relationship_transfer.

    Valid choices:

    - aborted
    - failed
    - hard_aborted
    - queued
    - success
    - transferring
  `total_duration: str GET POST PATCH`

    Elapsed time to transfer all snapshots for the last successful transfer.

    Example: PT28M41S

  `type: str GET POST PATCH`

    Specifies the operation type of the current transfer on the relationship. The initialize transfer occurs when the relationship state changes from "uninitialized" to "snapmirrored" or "in_sync". The update transfer occurs when snapshots are being transferred from the source endpoint to the destination endpoint as part of a scheduled or manual update. The resync transfer occurs when the relationship state changes from "broken_off" to "snapmirrored" or "in_sync". The restore transfer occurs when a snapshot is being restored from a destination endpoint to another endpoint.

    Valid choices:

    - initialize
    - update
    - resync
    - restore
  `uuid: str GET POST PATCH`

    Transfer UUID. This property is applicable only for active transfers.

    Example: 4ea7a442-86d1-11e0-ae1c-123478563412